@@ -240,12 +240,14 @@ class QuerySet(list):
     Attributes:
     ----------
         _root: the root json object from which the entire queryset is derived
+        _list_of_root_nodes: if this is a list of root nodes, coming from a parsed json instead of from a query
     """
 
-    def __init__(self, *args):
+    def __init__(self, *args, list_of_root_nodes=False):
         super().__init__(*args)
         self._root = None
         self._native_types = None
+        self._list_of_root_nodes = list_of_root_nodes
 
     def first(self):
 
@@ -279,6 +281,8 @@ class QuerySet(list):
         """
         Update elements of queryset (inplace) within JSONObject from which they are derived (self._root)
         """
+        if self._list_of_root_nodes:
+            return  # TODO if list of root nodes, call each node's query
 
         # TODO add test for update when callables
         is_callable = callable(new_obj)
@@ -344,10 +348,18 @@ class QuerySet(list):
         output._root = self._root
         output._native_types = self._native_types
 
-        for item in self:
-            if item.parent.query(**q).exists():
-                output.append(item)
-        return output
+        if (
+            self._list_of_root_nodes
+        ):  # If we are dealing with a list of root nodes, we must call the query function of each of them
+            for item in self:
+                if item.query(**q).exists():
+                    output.append(item)
+            return output
+        else:
+            for item in self:
+                if item.parent.query(**q).exists():
+                    output.append(item)
+            return output
 
     def values(self, *keys, search_upwards=True, **kwargs):
         """
@@ -359,7 +371,9 @@ class QuerySet(list):
             search_upwards: The function will try to search for the specified keys among the parents of each object
 
         """
-        # TODO call node values method for each item
+
+        if self._list_of_root_nodes:
+            return
 
         values_list = ValuesList(
             (
@@ -376,8 +390,23 @@ class QuerySet(list):
             values_list.append(output_dict)
         return values_list
 
+    def jsonpaths(self):
+        """
+        Returns a ValuesList with the jsonpath of each node
+        """
+
+        output = ValuesList()
+        output._root = self._root
+
+        for item in self:
+            output.append(item.jsonpath)
+
+        return output
+
     def order_by(self, key):
         # TODO
+        if self._list_of_root_nodes:
+            return
         rever = True if key.startswith("-") else False
 
         cls = self.__class__
@@ -403,6 +432,9 @@ class QuerySet(list):
     def sum(self):
         """Sum numbers on queryset"""
 
+        if self._list_of_root_nodes:
+            return
+
         if not self.exists():
             return
 
